@@ -1,4 +1,5 @@
 # Copyright 2013, Nachi Ueno, NTT I3, Inc.
+# Copyright 2017, Fujitsu Limited
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -14,13 +15,15 @@
 #    under the License.
 
 
-from neutron.agent.l3 import agent as l3_agent
-from neutron.agent import l3_agent as entry
+from neutron_lib.agent import l3_extension
 from oslo_config import cfg
+from oslo_log import log as logging
 
 from neutron_vpnaas._i18n import _
 from neutron_vpnaas.services.vpn import vpn_service
 
+LOG = logging.getLogger(__name__)
+
 vpn_agent_opts = [
     cfg.MultiStrOpt(
         'vpn_device_driver',
@@ -43,19 +46,52 @@ vpn_agent_opts = [
 cfg.CONF.register_opts(vpn_agent_opts, 'vpnagent')
 
 
-class VPNAgent(l3_agent.L3NATAgentWithStateReport):
-    """VPNAgent class which can handle vpn service drivers."""
-    def __init__(self, host, conf=None):
-        super(VPNAgent, self).__init__(host=host, conf=conf)
-        self.agent_state['binary'] = 'neutron-vpn-agent'
-        self.service = vpn_service.VPNService(self)
-        self.device_drivers = self.service.load_device_drivers(host)
+class VPNAgent(l3_extension.L3AgentExtension):
+    """VPNaaS Agent support to be used by Neutron L3 agent."""
 
-    def process_state_change(self, router_id, state):
+    def initialize(self, connection, driver_type):
+        LOG.debug("Loading VPNaaS")
+
+    def consume_api(self, agent_api):
+        LOG.debug("Loading consume_api for VPNaaS")
+        self.agent_api = agent_api
+
+    def __init__(self, host, conf):
+        LOG.debug("Initializing VPNaaS agent")
+        self.agent_api = None
+        self.conf = conf
+        self.host = host
+        self.service = vpn_service.VPNService(self)
+        self.device_drivers = self.service.load_device_drivers(self.host)
+
+    def add_router(self, context, data):
+        """Handles router add event"""
+        ri = self.agent_api.get_router_info(data['id'])
+        if ri is not None:
+            for device_driver in self.device_drivers:
+                device_driver.create_router(ri)
+                device_driver.sync(context, [ri.router])
+        else:
+            LOG.debug("Router %s was concurrently deleted while "
+                      "creating VPN for it", data['id'])
+
+    def update_router(self, context, data):
+        """Handles router update event"""
+        for device_driver in self.device_drivers:
+            device_driver.sync(context, [data])
+
+    def delete_router(self, context, data):
+        """Handles router delete event"""
+        for device_driver in self.device_drivers:
+            device_driver.destroy_router(data)
+
+    def ha_state_change(self, context, data):
         """Enable the vpn process when router transitioned to master.
 
-           And disable vpn process for backup router.
+        And disable vpn process for backup router.
         """
+        router_id = data['router_id']
+        state = data['state']
         for device_driver in self.device_drivers:
             if router_id in device_driver.processes:
                 process = device_driver.processes[router_id]
@@ -64,11 +100,13 @@ class VPNAgent(l3_agent.L3NATAgentWithStateReport):
                 else:
                     process.disable()
 
-    def enqueue_state_change(self, router_id, state):
-        """Handle HA router state changes for vpn process"""
-        self.process_state_change(router_id, state)
-        super(VPNAgent, self).enqueue_state_change(router_id, state)
 
+class L3WithVPNaaS(VPNAgent):
 
-def main():
-    entry.main(manager='neutron_vpnaas.services.vpn.agent.VPNAgent')
+    def __init__(self, conf=None):
+        if conf:
+            self.conf = conf
+        else:
+            self.conf = cfg.CONF
+        super(L3WithVPNaaS, self).__init__(
+            host=self.conf.host, conf=self.conf)
