@@ -19,6 +19,7 @@ import os
 import socket
 
 import mock
+import netaddr
 from neutron.agent.l3 import dvr_edge_router
 from neutron.agent.l3 import dvr_snat_ns
 from neutron.agent.l3 import legacy_router
@@ -137,7 +138,7 @@ OPENSWAN_CONNECTION_DETAILS = '''# rightsubnet=networkA/netmaskA, networkB/netma
     # IPsecPolicys params
     ##########################
     # [transform_protocol]
-    auth=%(auth_mode)s
+    phase2=%(auth_mode)s
     # [encapsulation_mode]
     type=%(encapsulation_mode)s
     # [lifetime_value]
@@ -161,6 +162,7 @@ EXPECTED_OPENSWAN_CONF = """
 # Configuration for myvpn
 config setup
     nat_traversal=yes
+    virtual_private=%(virtual_privates)s
 conn %%default
     ikelifetime=480m
     keylife=60m
@@ -291,12 +293,19 @@ EXPECTED_IPSEC_STRONGSWAN_SECRET_CONF = '''
 '''
 
 PLUTO_ACTIVE_STATUS = """000 "%(conn_id)s/0x1": erouted;\n
-000 #4: "%(conn_id)s/0x1":500 STATE_QUICK_R2 (IPsec SA established);""" % {
+000 #4: "%(conn_id)s/0x1":500 STATE_QUICK_R2 (IPsec SA established); \
+newest IPSEC;""" % {
+    'conn_id': FAKE_IPSEC_SITE_CONNECTION2_ID}
+PLUTO_ACTIVE_STATUS_IKEV2 = """000 "%(conn_id)s/0x1": erouted;\n
+000 #4: "%(conn_id)s/0x1":500 STATE_PARENT_R2 (PARENT SA established); \
+newest IPSEC;""" % {
     'conn_id': FAKE_IPSEC_SITE_CONNECTION2_ID}
 PLUTO_MULTIPLE_SUBNETS_ESTABLISHED_STATUS = """000 "%(conn_id1)s/1x1": erouted;\n
-000 #4: "%(conn_id1)s/1x1":500 STATE_QUICK_R2 (IPsec SA established);\n
+000 #4: "%(conn_id1)s/1x1":500 STATE_QUICK_R2 (IPsec SA established); \
+newest IPSEC;\n
 000 "%(conn_id2)s/2x1": erouted;\n
-000 #4: "%(conn_id2)s/2x1":500 STATE_QUICK_R2 (IPsec SA established);\n""" % {
+000 #4: "%(conn_id2)s/2x1":500 STATE_QUICK_R2 (IPsec SA established); \
+newest IPSEC;\n""" % {
     'conn_id1': FAKE_IPSEC_SITE_CONNECTION1_ID,
     'conn_id2': FAKE_IPSEC_SITE_CONNECTION2_ID}
 PLUTO_ACTIVE_NO_IPSEC_SA_STATUS = """000 "%(conn_id)s/0x1": erouted;\n
@@ -343,8 +352,7 @@ class BaseIPsecDeviceDriver(base.BaseTestCase):
     @staticmethod
     def generate_diff(a, b):
         """Generates unified diff of a and b."""
-        by_lines = lambda x: x.splitlines(True)
-        a, b = list(by_lines(a)), list(by_lines(b))
+        a, b = list(a.splitlines(True)), list(b.splitlines(True))
         diff = difflib.unified_diff(a, b, fromfile="expected",
                                     tofile="actual")
         return diff
@@ -797,6 +805,29 @@ class IPSecDeviceLegacy(BaseIPsecDeviceDriver):
         self.assertEqual(constants.ACTIVE,
                          ipsec_site_conn[connection_id]['status'])
 
+    def _test_status_handling_for_ike_v2_active_connection(self,
+            active_status):
+        """Test status handling for active connection."""
+        router_id = self.router.router_id
+        connection_id = FAKE_IPSEC_SITE_CONNECTION2_ID
+        ike_policy = {'ike_version': 'v2',
+                      'encryption_algorithm': 'aes-128',
+                      'auth_algorithm': 'sha1',
+                      'pfs': 'group5',
+                      'lifetime_value': 3600}
+        vpn_service = FAKE_VPN_SERVICE
+        for isc in vpn_service["ipsec_site_connections"]:
+            isc['ikepolicy'] = ike_policy
+        self.driver.ensure_process(router_id, vpn_service)
+        self._execute.return_value = active_status
+        self.driver.report_status(mock.Mock())
+        process_status = self.driver.process_status_cache[
+            router_id]
+        ipsec_site_conn = process_status['ipsec_site_connections']
+        self.assertEqual(constants.ACTIVE, process_status['status'])
+        self.assertEqual(constants.ACTIVE,
+                         ipsec_site_conn[connection_id]['status'])
+
     def _test_connection_names_handling_for_multiple_subnets(self,
                                                              active_status):
         """Test connection names handling for multiple subnets."""
@@ -960,6 +991,7 @@ class TestOpenSwanConfigGeneration(BaseIPsecDeviceDriver):
                 'ike_lifetime': 3600,
                 'life_time': 3600,
                 'encapsulation_mode': 'tunnel'}
+        virtual_privates = []
         # Convert local CIDRs into assignment strings. IF more than one,
         # pluralize the attribute name and enclose in brackets.
         cidrs = info.get('local_cidrs', [['10.0.0.0/24'], ['11.0.0.0/24']])
@@ -969,15 +1001,24 @@ class TestOpenSwanConfigGeneration(BaseIPsecDeviceDriver):
                 local_cidrs.append("s={ %s }" % ' '.join(cidr))
             else:
                 local_cidrs.append("=%s" % cidr[0])
+            for net in cidr:
+                version = netaddr.IPNetwork(net).version
+                virtual_privates.append('%%v%s:%s' % (version, net))
         # Convert peer CIDRs into space separated strings
         cidrs = info.get('peer_cidrs', [['20.0.0.0/24', '30.0.0.0/24'],
                                         ['40.0.0.0/24', '50.0.0.0/24']])
+        for cidr in cidrs:
+            for net in cidr:
+                version = netaddr.IPNetwork(net).version
+                virtual_privates.append('%%v%s:%s' % (version, net))
         peer_cidrs = [' '.join(cidr) for cidr in cidrs]
         local_ip = info.get('local', '60.0.0.4')
         version = info.get('local_ip_vers', 4)
         next_hop = IPV4_NEXT_HOP if version == 4 else IPV6_NEXT_HOP % local_ip
         peer_ips = info.get('peers', ['60.0.0.5', '60.0.0.6'])
+        virtual_privates.sort()
         return EXPECTED_OPENSWAN_CONF % {
+            'virtual_privates': ','.join(virtual_privates),
             'next_hop': next_hop,
             'local_cidrs1': local_cidrs[0], 'local_cidrs2': local_cidrs[1],
             'local_ver': version,
@@ -1381,6 +1422,11 @@ class TestOpenSwanProcess(IPSecDeviceLegacy):
         """Test status handling for active connection."""
         self._test_status_handling_for_active_connection(PLUTO_ACTIVE_STATUS)
 
+    def test_status_handling_for_ike_v2_active_connection(self):
+        """Test status handling for active connection."""
+        self._test_status_handling_for_ike_v2_active_connection(
+            PLUTO_ACTIVE_STATUS_IKEV2)
+
     def test_status_handling_for_deleted_connection(self):
         """Test status handling for deleted connection."""
         self._test_status_handling_for_deleted_connection(NOT_RUNNING_STATUS)
@@ -1412,17 +1458,29 @@ class TestLibreSwanProcess(base.BaseTestCase):
     @mock.patch('os.path.exists', return_value=True)
     def test_ensure_configs_on_restart(self, exists_mock, remove_mock):
         openswan_ipsec.OpenSwanProcess.ensure_configs = mock.Mock()
-        with mock.patch.object(self.ipsec_process, '_execute') as fake_execute:
+        with mock.patch.object(
+            self.ipsec_process, '_execute'
+        ) as fake_execute, mock.patch.object(
+            self.ipsec_process, '_ipsec_execute'
+        ) as fake_ipsec_execute, mock.patch.object(
+            self.ipsec_process, '_ensure_needed_files'
+        ) as fake_ensure_needed_files:
             self.ipsec_process.ensure_configs()
             expected = [mock.call(['chown', '--from=%s' % os.getuid(),
                                    'root:root',
                                    self.ipsec_process._get_config_filename(
                                        'ipsec.secrets')]),
-                        mock.call(['ipsec', '_stackmanager', 'start']),
-                        mock.call(['ipsec', 'checknss',
-                                   self.ipsec_process.etc_dir])]
+                        mock.call(['chown', '--from=%s' % os.getuid(),
+                                   'root:root', self.ipsec_process.log_dir])]
             fake_execute.assert_has_calls(expected)
-            self.assertEqual(3, fake_execute.call_count)
+            self.assertEqual(2, fake_execute.call_count)
+
+            expected = [mock.call(['_stackmanager', 'start']),
+                        mock.call(['checknss'])]
+            fake_ipsec_execute.assert_has_calls(expected)
+            self.assertEqual(2, fake_ipsec_execute.call_count)
+
+            self.assertTrue(fake_ensure_needed_files.called)
             self.assertTrue(exists_mock.called)
             self.assertTrue(remove_mock.called)
 
@@ -1430,37 +1488,62 @@ class TestLibreSwanProcess(base.BaseTestCase):
     @mock.patch('os.path.exists', return_value=False)
     def test_ensure_configs(self, exists_mock, remove_mock):
         openswan_ipsec.OpenSwanProcess.ensure_configs = mock.Mock()
-        with mock.patch.object(self.ipsec_process, '_execute') as fake_execute:
+        with mock.patch.object(
+            self.ipsec_process, '_execute'
+        ) as fake_execute, mock.patch.object(
+            self.ipsec_process, '_ipsec_execute'
+        ) as fake_ipsec_execute, mock.patch.object(
+            self.ipsec_process, '_ensure_needed_files'
+        ) as fake_ensure_needed_files:
             self.ipsec_process.ensure_configs()
+
             expected = [mock.call(['chown', '--from=%s' % os.getuid(),
                                    'root:root',
                                    self.ipsec_process._get_config_filename(
                                        'ipsec.secrets')]),
-                        mock.call(['ipsec', '_stackmanager', 'start']),
-                        mock.call(['ipsec', 'checknss',
-                                   self.ipsec_process.etc_dir])]
+                        mock.call(['chown', '--from=%s' % os.getuid(),
+                                   'root:root', self.ipsec_process.log_dir])]
             fake_execute.assert_has_calls(expected)
-            self.assertEqual(3, fake_execute.call_count)
+            self.assertEqual(2, fake_execute.call_count)
+
+            expected = [mock.call(['_stackmanager', 'start']),
+                        mock.call(['checknss'])]
+            fake_ipsec_execute.assert_has_calls(expected)
+            self.assertEqual(2, fake_ipsec_execute.call_count)
+
+            self.assertTrue(fake_ensure_needed_files.called)
             self.assertTrue(exists_mock.called)
             self.assertFalse(remove_mock.called)
 
         exists_mock.reset_mock()
         remove_mock.reset_mock()
 
-        with mock.patch.object(self.ipsec_process, '_execute') as fake_execute:
-            fake_execute.side_effect = [None, None, RuntimeError, None]
+        with mock.patch.object(
+            self.ipsec_process, '_execute'
+        ) as fake_execute, mock.patch.object(
+            self.ipsec_process, '_ipsec_execute'
+        ) as fake_ipsec_execute, mock.patch.object(
+            self.ipsec_process, '_ensure_needed_files'
+        ) as fake_ensure_needed_files:
+            fake_ipsec_execute.side_effect = [None, RuntimeError, None]
             self.ipsec_process.ensure_configs()
+
             expected = [mock.call(['chown', '--from=%s' % os.getuid(),
                                    'root:root',
                                    self.ipsec_process._get_config_filename(
                                        'ipsec.secrets')]),
-                        mock.call(['ipsec', '_stackmanager', 'start']),
-                        mock.call(['ipsec', 'checknss',
-                                   self.ipsec_process.etc_dir]),
-                        mock.call(['ipsec', 'initnss',
-                                   self.ipsec_process.etc_dir])]
+                        mock.call(['chown', '--from=%s' % os.getuid(),
+                                   'root:root', self.ipsec_process.log_dir])]
             fake_execute.assert_has_calls(expected)
-            self.assertEqual(4, fake_execute.call_count)
+            self.assertEqual(2, fake_execute.call_count)
+
+            expected = [mock.call(['_stackmanager', 'start']),
+                        mock.call(['checknss']),
+                        mock.call(['initnss'])]
+            self.assertEqual(3, fake_ipsec_execute.call_count)
+            fake_ipsec_execute.assert_has_calls(expected)
+
+            self.assertTrue(fake_ensure_needed_files.called)
             self.assertTrue(exists_mock.called)
             self.assertFalse(remove_mock.called)
 
